package com.vendor.burn.model.devices.unknown;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import com.vendor.burn.model.FlashType;
import com.vendor.burn.model.define.IBurner;
import com.vendor.burn.model.devices.IFlashSetting;
import com.vendor.burn.model.devices.unknown.UDProperties;
import com.vendor.burn.utilitily.ToolUtils;
import com.vendor.burn.views.FastbootView;
import java.util.ArrayList;

public class UDFlashSetting implements IFlashSetting {
  FlashType[] flashTypesForPartitionAndAddressBurner;
  
  FlashType[] flashTypesForEmmcBurner;
  
  FlashType[] flashTypesForBootBurner;
  
  FlashType[] flashTypesForMergeBurner;
  
  FlashType[] flashTypesForCommonBurner;
  
  FlashType[] flashTypesForCmdLineBurner;
  
  public static com.vendor.burn.model.devices.unknown.UDFlashSetting build(UDProperties properties) {
    com.vendor.burn.model.devices.unknown.UDFlashSetting flashSetting = new com.vendor.burn.model.devices.unknown.UDFlashSetting();
    if (flashSetting.init(properties))
      return flashSetting; 
    return null;
  }
  
  private boolean init(UDProperties properties) {
    String chipNameType = properties.queryForString("ChipNameType");
    FastbootView.setCurrentChipNameType(chipNameType);
    ArrayList<FlashType> flashList = new ArrayList<>();
    Integer notNandInt = properties.queryForInteger("NOTNAND");
    if (notNandInt == null)
      flashList.add(FlashType.nand); 
    Integer notSpiInt = properties.queryForInteger("NOTSPI");
    if (notSpiInt == null)
      flashList.add(FlashType.spi); 
    Integer eepromInt = properties.queryForInteger("EEPROM");
    if (eepromInt != null && eepromInt.intValue() == 1)
      flashList.add(FlashType.eeprom); 
    this.flashTypesForPartitionAndAddressBurner = new FlashType[flashList.size()];
    flashList.toArray(this.flashTypesForPartitionAndAddressBurner);
    flashList.clear();
    if (notNandInt == null)
      flashList.add(FlashType.nand); 
    if (notSpiInt == null)
      flashList.add(FlashType.spi); 
    if (eepromInt != null && eepromInt.intValue() == 1)
      flashList.add(FlashType.eeprom); 
    flashList.add(FlashType.ddr);
    this.flashTypesForBootBurner = new FlashType[flashList.size()];
    flashList.toArray(this.flashTypesForBootBurner);
    flashList.clear();
    Integer ssdInt = properties.queryForInteger("SSD");
    Integer ufsInt = properties.queryForInteger("UFS");
    initEmmcBurnerFlashType(ssdInt, ufsInt);
    if (notNandInt == null)
      flashList.add(FlashType.nand); 
    if (notSpiInt == null)
      flashList.add(FlashType.spi); 
    if (eepromInt != null && eepromInt.intValue() == 1)
      flashList.add(FlashType.eeprom); 
    flashList.add(FlashType.emmc);
    if (ufsInt != null && ufsInt.intValue() == 1) {
      flashList.add(FlashType.ufs);
      flashList.add(FlashType.ufs1);
    } 
    initFlash(flashList);
    if (ssdInt != null && ssdInt.intValue() == 1)
      flashList.add(FlashType.ssd); 
    this.flashTypesForMergeBurner = new FlashType[flashList.size()];
    flashList.toArray(this.flashTypesForMergeBurner);
    if (ToolUtils.isCmdLine()) {
      this.flashTypesForCmdLineBurner = new FlashType[flashList.size()];
      flashList.toArray(this.flashTypesForCmdLineBurner);
    } else {
      this.flashTypesForCommonBurner = new FlashType[flashList.size()];
      flashList.toArray(this.flashTypesForCommonBurner);
    } 
    flashList.clear();
    return true;
  }
  
  private void initEmmcBurnerFlashType(Integer ssdInt, Integer ufsInt) {
    ArrayList<FlashType> flashList = new ArrayList<>();
    flashList.add(FlashType.emmc);
    if (ssdInt != null && ssdInt.intValue() == 1)
      flashList.add(FlashType.ssd); 
    if (ufsInt != null && ufsInt.intValue() == 1) {
      flashList.add(FlashType.ufs);
      flashList.add(FlashType.ufs1);
    } 
    initFlash(flashList);
    this.flashTypesForEmmcBurner = new FlashType[flashList.size()];
    flashList.toArray(this.flashTypesForEmmcBurner);
  }
  
  private void initFlash(ArrayList<FlashType> flashList) {
    flashList.add(FlashType.emmcboot0);
    flashList.add(FlashType.emmcboot1);
    flashList.add(FlashType.emmcboot2);
    flashList.add(FlashType.emmc0);
    flashList.add(FlashType.emmc1);
    flashList.add(FlashType.emmc2);
  }
  
  public FlashType[] getFlashTypes(IBurner burner) {
    if (ToolUtils.isCmdLine())
      return (FlashType[])this.flashTypesForCmdLineBurner.clone(); 
    if (burner instanceof com.vendor.burn.model.devices.ICommonBurner)
      return (FlashType[])this.flashTypesForCommonBurner.clone(); 
    if (burner instanceof com.vendor.burn.model.devices.IEmmcBurner)
      return (FlashType[])this.flashTypesForEmmcBurner.clone(); 
    if (burner instanceof com.vendor.burn.model.devices.IMergeBurner)
      return (FlashType[])this.flashTypesForMergeBurner.clone(); 
    if (burner instanceof com.vendor.burn.model.devices.IPartitionBurner)
      return (FlashType[])this.flashTypesForPartitionAndAddressBurner.clone(); 
    if (burner instanceof com.vendor.burn.model.devices.IAddressBurner)
      return (FlashType[])this.flashTypesForPartitionAndAddressBurner.clone(); 
    if (burner instanceof com.vendor.burn.model.devices.IBootBurner)
      return (FlashType[])this.flashTypesForBootBurner.clone(); 
    return new FlashType[0];
  }
  
  public String[] getFlashNames(IBurner burner) {
    FlashType[] flashTypes = getFlashTypes(burner);
    String[] result = new String[flashTypes.length];
    for (int i = 0; i < result.length; i++) {
      if (flashTypes[i] == FlashType.nand) {
        result[i] = "spi nand/nand";
      } else if (flashTypes[i] == FlashType.spi) {
        result[i] = "spi nor";
      } else {
        result[i] = flashTypes[i].name();
      } 
    } 
    return result;
  }
  
  public FlashType findFlashType(String name) {
    if (name.equalsIgnoreCase("spi nand/nand")) {
      name = FlashType.nand.name();
    } else if (name.equalsIgnoreCase("spi nor")) {
      name = FlashType.spi.name();
    } 
    FlashType[] values = FlashType.values();
    for (FlashType flashType : values) {
      if (flashType.name().equalsIgnoreCase(name))
        return flashType; 
    } 
    return null;
  }
  
  public FlashType findFlashType(IBurner burner, String name) {
    if (name.equalsIgnoreCase("spi nand/nand")) {
      name = FlashType.nand.name();
    } else if (name.equalsIgnoreCase("spi nor")) {
      name = FlashType.spi.name();
    } 
    FlashType[] values = getFlashTypes(burner);
    for (FlashType flashType : values) {
      if (flashType.name().equalsIgnoreCase(name))
        return flashType; 
    } 
    return null;
  }
}
